@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 #
 # Author:: Kurt Yoder (ktyopscode@yoderhome.com)
 # Copyright:: Copyright (c) 2010 Kurt Yoder
@@ -76,7 +77,7 @@ Ohai.plugin(:DMI) do
           dmi[:table_location] = table_location[1]
 
         elsif ( handle = handle_line.match(line) )
-          unless Ohai::Common::DMI.whitelisted_ids.include?(handle[2].to_i)
+          unless Ohai::Common::DMI.allowlisted_ids.include?(handle[2].to_i)
             dmi_record = nil
             next
           end
@@ -92,14 +93,14 @@ Ohai.plugin(:DMI) do
           field = nil
 
         elsif ( type = type_line.match(line) )
-          if dmi_record .nil?
+          if dmi_record.nil?
             logger.trace("Plugin DMI: unexpected data line found before header; discarding:\n#{line}")
             next
           end
           dmi[dmi_record[:type]][:all_records][dmi_record[:position]][:application_identifier] = type[1]
 
         elsif ( data = data_line.match(line) )
-          if dmi_record .nil?
+          if dmi_record.nil?
             logger.trace("Plugin DMI: unexpected data line found before header; discarding:\n#{line}")
             next
           end
@@ -107,11 +108,11 @@ Ohai.plugin(:DMI) do
           field = data[1]
 
         elsif ( extended_data = extended_data_line.match(line) )
-          if dmi_record .nil?
+          if dmi_record.nil?
             logger.trace("Plugin DMI: unexpected extended data line found before header; discarding:\n#{line}")
             next
           end
-          if field .nil?
+          if field.nil?
             logger.trace("Plugin DMI: unexpected extended data line found outside data section; discarding:\n#{line}")
             next
           end
