@@ -1,6 +1,7 @@
+# frozen_string_literal: true
 #
 # Author:: Thom May (<thom@clearairturbulence.org>)
-# Copyright:: Copyright (c) 2009-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -51,15 +52,15 @@ Ohai.plugin(:Virtualization) do
     # - may be able to determine if under paravirt from /dev/xen/evtchn (See OHAI-253)
     # - Additional edge cases likely should not change the above assumptions
     #   but rather be additive - btm
-    if File.exist?("/proc/xen")
+    if file_exist?("/proc/xen")
       virtualization[:system] = "xen"
       # Assume guest
       virtualization[:role] = "guest"
       virtualization[:systems][:xen] = "guest"
 
       # This file should exist on most Xen systems, normally empty for guests
-      if File.exist?("/proc/xen/capabilities")
-        if File.read("/proc/xen/capabilities") =~ /control_d/i
+      if file_exist?("/proc/xen/capabilities")
+        if /control_d/i.match?(file_read("/proc/xen/capabilities"))
           logger.trace("Plugin Virtualization: /proc/xen/capabilities contains control_d. Detecting as Xen host")
           virtualization[:role] = "host"
           virtualization[:systems][:xen] = "host"
@@ -68,14 +69,14 @@ Ohai.plugin(:Virtualization) do
     end
 
     # Detect Virtualbox from kernel module
-    if File.exist?("/proc/modules")
-      modules = File.read("/proc/modules")
-      if modules =~ /^vboxdrv/
+    if file_exist?("/proc/modules")
+      modules = file_read("/proc/modules")
+      if /^vboxdrv/.match?(modules)
         logger.trace("Plugin Virtualization: /proc/modules contains vboxdrv. Detecting as vbox host")
         virtualization[:system] = "vbox"
         virtualization[:role] = "host"
         virtualization[:systems][:vbox] = "host"
-      elsif modules =~ /^vboxguest/
+      elsif /^vboxguest/.match?(modules)
         logger.trace("Plugin Virtualization: /proc/modules contains vboxguest. Detecting as vbox guest")
         virtualization[:system] = "vbox"
         virtualization[:role] = "guest"
@@ -92,8 +93,8 @@ Ohai.plugin(:Virtualization) do
     end
 
     # Detect paravirt KVM/QEMU from cpuinfo, report as KVM
-    if File.exist?("/proc/cpuinfo")
-      if File.read("/proc/cpuinfo") =~ /QEMU Virtual CPU|Common KVM processor|Common 32-bit KVM processor/
+    if file_exist?("/proc/cpuinfo")
+      if /QEMU Virtual CPU|Common KVM processor|Common 32-bit KVM processor/.match?(file_read("/proc/cpuinfo"))
         logger.trace("Plugin Virtualization: /proc/cpuinfo lists a KVM paravirt CPU string. Detecting as kvm guest")
         virtualization[:system] = "kvm"
         virtualization[:role] = "guest"
@@ -103,9 +104,9 @@ Ohai.plugin(:Virtualization) do
 
     # Detect KVM systems via /sys
     # guests will have the hypervisor cpu feature that hosts don't have
-    if File.exist?("/sys/devices/virtual/misc/kvm")
+    if file_exist?("/sys/devices/virtual/misc/kvm")
       virtualization[:system] = "kvm"
-      if File.read("/proc/cpuinfo") =~ /hypervisor/
+      if /hypervisor/.match?(file_read("/proc/cpuinfo"))
         logger.trace("Plugin Virtualization: /sys/devices/virtual/misc/kvm present and /proc/cpuinfo lists the hypervisor feature. Detecting as kvm guest")
         virtualization[:role] = "guest"
         virtualization[:systems][:kvm] = "guest"
@@ -118,8 +119,8 @@ Ohai.plugin(:Virtualization) do
 
     # parse dmi to discover various virtualization guests
     # we do this *after* the kvm detection so that OpenStack isn't detected as KVM
-    logger.trace("Looking up DMI data manufacturer: '#{get_attribute(:dmi, :system, :manufacturer)}' product: '#{get_attribute(:dmi, :system, :product)}' version: '#{get_attribute(:dmi, :system, :version)}'")
-    guest = guest_from_dmi_data(get_attribute(:dmi, :system, :manufacturer), get_attribute(:dmi, :system, :product), get_attribute(:dmi, :system, :version))
+    logger.trace("Looking up DMI data manufacturer: '#{get_attribute(:dmi, :system, :manufacturer)}' product_name: '#{get_attribute(:dmi, :system, :product_name)}' version: '#{get_attribute(:dmi, :system, :version)}'")
+    guest = guest_from_dmi_data(get_attribute(:dmi, :system, :manufacturer), get_attribute(:dmi, :system, :product_name), get_attribute(:dmi, :system, :version))
     if guest
       logger.trace("Plugin Virtualization: DMI data indicates #{guest} guest")
       virtualization[:system] = guest
@@ -129,12 +130,12 @@ Ohai.plugin(:Virtualization) do
 
     # Detect OpenVZ / Virtuozzo.
     # http://wiki.openvz.org/BC_proc_entries
-    if File.exist?("/proc/bc/0")
+    if file_exist?("/proc/bc/0")
       logger.trace("Plugin Virtualization: /proc/bc/0 exists. Detecting as openvz host")
       virtualization[:system] = "openvz"
       virtualization[:role] = "host"
       virtualization[:systems][:openvz] = "host"
-    elsif File.exist?("/proc/vz")
+    elsif file_exist?("/proc/vz")
       logger.trace("Plugin Virtualization: /proc/vz exists. Detecting as openvz guest")
       virtualization[:system] = "openvz"
       virtualization[:role] = "guest"
@@ -142,9 +143,9 @@ Ohai.plugin(:Virtualization) do
     end
 
     # Detect Hyper-V guest and the hostname of the host
-    if File.exist?("/var/lib/hyperv/.kvp_pool_3")
+    if file_exist?("/var/lib/hyperv/.kvp_pool_3")
       logger.trace("Plugin Virtualization: /var/lib/hyperv/.kvp_pool_3 contains string indicating Hyper-V guest")
-      data = File.read("/var/lib/hyperv/.kvp_pool_3")
+      data = file_read("/var/lib/hyperv/.kvp_pool_3")
       hyperv_host = data[/\HostName(.*?)HostingSystemEditionId/, 1].scan(/[[:print:]]/).join.downcase
       virtualization[:system] = "hyperv"
       virtualization[:role] = "guest"
@@ -153,8 +154,8 @@ Ohai.plugin(:Virtualization) do
     end
 
     # Detect Linux-VServer
-    if File.exist?("/proc/self/status")
-      proc_self_status = File.read("/proc/self/status")
+    if file_exist?("/proc/self/status")
+      proc_self_status = file_read("/proc/self/status")
       vxid = proc_self_status.match(/^(s_context|VxID):\s*(\d+)$/)
       if vxid && vxid[2]
         virtualization[:system] = "linux-vserver"
@@ -188,25 +189,28 @@ Ohai.plugin(:Virtualization) do
     #
     # Full notes, https://tickets.opscode.com/browse/OHAI-551
     # Kernel docs, https://www.kernel.org/doc/Documentation/cgroups
-    if File.exist?("/proc/self/cgroup")
-      cgroup_content = File.read("/proc/self/cgroup")
-      if cgroup_content =~ %r{^\d+:[^:]+:/(lxc|docker)/.+$} ||
-          cgroup_content =~ %r{^\d+:[^:]+:/[^/]+/(lxc|docker)-?.+$}
+    if file_exist?("/proc/self/cgroup")
+      cgroup_content = file_read("/proc/self/cgroup")
+      # These two REs catch many different examples. Here's a specific one
+      # from when it is docker and there is no subsystem name.
+      # https://rubular.com/r/dV13hiU9KxmiWB
+      if cgroup_content =~ %r{^\d+:[^:]*:/(lxc|docker)/.+$} ||
+          cgroup_content =~ %r{^\d+:[^:]*:/[^/]+/(lxc|docker)-?.+$}
         logger.trace("Plugin Virtualization: /proc/self/cgroup indicates #{$1} container. Detecting as #{$1} guest")
         virtualization[:system] = $1
         virtualization[:role] = "guest"
         virtualization[:systems][$1.to_sym] = "guest"
-      elsif File.read("/proc/1/environ") =~ /container=lxc/
+      elsif /container=lxc/.match?(file_read("/proc/1/environ"))
         logger.trace("Plugin Virtualization: /proc/1/environ indicates lxc container. Detecting as lxc guest")
         virtualization[:system] = "lxc"
         virtualization[:role] = "guest"
         virtualization[:systems][:lxc] = "guest"
-      elsif File.read("/proc/1/environ") =~ /container=systemd-nspawn/
+      elsif /container=systemd-nspawn/.match?(file_read("/proc/1/environ"))
         logger.trace("Plugin Virtualization: /proc/1/environ indicates nspawn container. Detecting as nspawn guest")
         virtualization[:system] = "nspawn"
         virtualization[:role] = "guest"
         virtualization[:systems][:nspawn] = "guest"
-      elsif lxc_version_exists? && File.read("/proc/self/cgroup") =~ %r{\d:[^:]+:/$}
+      elsif lxc_version_exists? && file_read("/proc/self/cgroup") =~ %r{\d:[^:]+:/$}
         # lxc-version shouldn't be installed by default
         # Even so, it is likely we are on an LXC capable host that is not being used as such
         # So we're cautious here to not overwrite other existing values (OHAI-573)
@@ -221,7 +225,11 @@ Ohai.plugin(:Virtualization) do
         # If so, we may need to look further for a differentiator (OHAI-573)
         virtualization[:systems][:lxc] = "host"
       end
-    elsif File.exist?("/.dockerenv") || File.exist?("/.dockerinit")
+    end
+
+    # regardless of what we found above, if we're a docker container inside
+    # of the above, lets report as a docker container
+    if file_exist?("/.dockerenv") || file_exist?("/.dockerinit")
       logger.trace("Plugin Virtualization: .dockerenv or .dockerinit exist. Detecting as docker guest")
       virtualization[:system] = "docker"
       virtualization[:role] = "guest"
@@ -230,7 +238,7 @@ Ohai.plugin(:Virtualization) do
 
     # Detect LXD
     # See https://github.com/lxc/lxd/blob/master/doc/dev-lxd.md
-    if File.exist?("/dev/lxd/sock")
+    if file_exist?("/dev/lxd/sock")
       logger.trace("Plugin Virtualization: /dev/lxd/sock exists. Detecting as lxd guest")
       virtualization[:system] = "lxd"
       virtualization[:role] = "guest"
@@ -245,7 +253,7 @@ Ohai.plugin(:Virtualization) do
       # Snap based installations utilize '/var/snap/lxd/common/lxd/'
       #   - includes all future releases starting with 2.21, and will be the only source of 3.1+ feature releases post-bionic
       ["/var/lib/lxd/devlxd", "/var/snap/lxd/common/lxd/devlxd"].each do |devlxd|
-        if File.exist?(devlxd)
+        if file_exist?(devlxd)
           logger.trace("Plugin Virtualization: #{devlxd} exists. Detecting as lxd host")
           virtualization[:system] = "lxd"
           virtualization[:role] = "host"
