@@ -1,6 +1,7 @@
+# frozen_string_literal: true
 #
 # Author:: Stuart Preston (<stuart@chef.io>)
-# Copyright:: Copyright (c) 2018, Chef Software Inc.
+# Copyright:: Copyright (c) Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,13 +19,11 @@
 
 Ohai.plugin :SystemEnclosure do
   provides "system_enclosure"
+  depends "dmi"
 
   collect_data(:windows) do
-    require "wmi-lite/wmi"
     system_enclosure Mash.new
-    wmi = WmiLite::Wmi.new
-    wmi_object = wmi.first_of("Win32_SystemEnclosure").wmi_ole_object
-    system_enclosure[:manufacturer] = wmi_object.invoke("manufacturer")
-    system_enclosure[:serialnumber] = wmi_object.invoke("serialnumber")
+    system_enclosure[:manufacturer] = get_attribute(:dmi, :chassis, :manufacturer)
+    system_enclosure[:serialnumber] = get_attribute(:dmi, :chassis, :serial_number)
   end
 end
