@@ -1,6 +1,7 @@
+# frozen_string_literal: true
 #
 # Author:: Adam Jacob (<adam@chef.io>)
-# Copyright:: Copyright (c) 2008-2018, Chef Software Inc.
+# Copyright:: Copyright (c) Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,6 +18,6 @@
 #
 
 module Ohai
-  OHAI_ROOT = File.expand_path(File.dirname(__FILE__))
-  VERSION = "16.0.7".freeze
+  OHAI_ROOT = File.expand_path(__dir__)
+  VERSION = "16.13.0"
 end
